//==================================================
// RipjackRazor
//
// Author: Radiosity
//==================================================

class RipjackRazor extends Projectile;

var Emitter		Trail1;
var() class<DamageType>	DamageTypeHeadShot;
var() float		HeadShotRadius, DamageAtten;
var bool		bBounced; // set after the first bounce - needed for self damaging

simulated function PostBeginPlay()
{
	if (Level.Netmode != NM_DedicatedServer)
	{
		Trail1 = Spawn(class'RipjackTrail',,, Location);
		Trail1.SetBase(self);
	}

	Velocity=Speed*Vector(Rotation);

	if (PhysicsVolume.bWaterVolume)
        Velocity *= 0.65;

	Super.PostBeginPlay();
}

simulated function Destroyed()
{
	if(Trail1 != None)
	Trail1.Destroy();

	Super.Destroyed();
}

simulated function ProcessTouch (Actor Other, vector HitLocation)
{
	local vector	x;
	local float	dist;

	if ( (RipjackRazor(Other) == None) && ((bBounced) || (Other != Instigator)) )
	{
        	speed = VSize(Velocity);
	        if ( speed > 200 )
        	{
		        if ( Role == ROLE_Authority )
				if (!Other.bWorldGeometry)
				{
					// handle headshots here
					if ((Pawn(Other) != None) && Other.GetClosestBone( HitLocation, x, dist, 'head', HeadShotRadius) == 'head' )
                        			Other.TakeDamage(250, Instigator, HitLocation, x, DamageTypeHeadShot);
						else
                				Other.TakeDamage(Max(5, Damage - DamageAtten*FMax(0,(default.LifeSpan - LifeSpan - 1))), Instigator, HitLocation, (MomentumTransfer * Velocity/speed), MyDamageType);
				}
        	}
	Destroy();
	}
}

simulated function HitWall( vector HitNormal, actor Wall )
{
	if ( (Mover(Wall) != None) && Mover(Wall).bDamageTriggered )
	{
        	if ( Level.NetMode != NM_Client )
		Wall.TakeDamage( Damage, instigator, Location, MomentumTransfer * Normal(Velocity), MyDamageType);

        	Destroy();

        	return;
	}

	bBounced = True;

	Velocity = 0.95 * (Velocity - 2.0*HitNormal*(Velocity dot HitNormal)); // slow the projectile after bounce

	SetRotation(rotator(Velocity));

	PlaySound(sound'ripjackSounds.Ripjack_Chink',SLOT_None,0.6,,300,0.9+frand()*0.2);
        if ( EffectIsRelevant(Location,false) )
            Spawn(class'RipjackImpact',,,, rotator(hitnormal));
}

simulated function PhysicsVolumeChange( PhysicsVolume Volume )
{
	if (Volume.bWaterVolume)
	{
        	if ( Trail1 != None )
		Trail1.Destroy();

        	Velocity *= 0.85;
	}
}

defaultproperties
{
	DamageAtten=2.0
	Speed=2000.000000
	MaxSpeed=2000.000000
	Damage=40.000000
	MomentumTransfer=7500.000000

	CullDistance=+8000.0
	NetPriority=2.500000

	MyDamageType=Class'Ripjack.DamTypeRipjackRazor'
	DamageTypeHeadShot=Class'Ripjack.DamTypeRipjackRazorHeadshot'

	DrawType=DT_Mesh
	Mesh=Mesh'ripjackAnim.RipbladeMesh'
	LifeSpan=6.000000
	DrawScale=0.550000
	AmbientGlow=254
	Style=STY_Alpha

	AmbientSound=Sound'ripjackSounds.Ripjack_RazorHum'

	FluidSurfaceShootStrengthMod=1.f

	SoundRadius=120.000000
	SoundVolume=70.000000

	CollisionHeight=7.000000
	CollisionRadius=25.000000

	bBounce=True
}

